==> sl7_fwork_flutter-0.0.1.tar.gz: lib/utils.dart <==
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:pdf/pdf.dart';
import 'package:pdf/widgets.dart' as pw;
import 'package:printing/printing.dart';
import 'package:string_validator/string_validator.dart';
import 'package:url_launcher/url_launcher.dart';

import 'widgets/staggeredDotsWave/staggered_dots_wave.dart';

final RouteObserver<PageRoute> routeObserver = RouteObserver<PageRoute>();

//LAYOUT
enum Layouts {
  fullDrawer,
  onlyTicketDrawer,
  noDrawer,
}

const double screenResolutionFactor = 0;

class ScreenResolutions {
  static double get xs => 600 - screenResolutionFactor;
  static double get sm => 960 - screenResolutionFactor;
  static double get md => 1280 - screenResolutionFactor;
  static double get lg => 1920 - screenResolutionFactor;
  static double get xl => 1921 - screenResolutionFactor;
}

double getScreenResolution(BuildContext context) {
  final width = MediaQuery.of(context).size.width;
  return width <= ScreenResolutions.xs
      ? ScreenResolutions.xs
      : width > ScreenResolutions.xs && width <= ScreenResolutions.sm
          ? ScreenResolutions.sm
          : width > ScreenResolutions.sm && width <= ScreenResolutions.md
              ? ScreenResolutions.md
              : width > ScreenResolutions.md && width <= ScreenResolutions.lg
                  ? ScreenResolutions.lg
                  : ScreenResolutions.xl;
}

Layouts getLayout(BuildContext context) {
  return [ScreenResolutions.xs, ScreenResolutions.sm]
          .contains(getScreenResolution(context))
      ? Layouts.fullDrawer
      : getScreenResolution(context) == ScreenResolutions.md
          ? Layouts.onlyTicketDrawer
          : [ScreenResolutions.lg, ScreenResolutions.xl]
                  .contains(getScreenResolution(context))
              ? Layouts.noDrawer
              : Layouts.fullDrawer;
}

//COLORS
Map<String, Color> colors = {
  'amber': Colors.amber,
  'amberAccent': Colors.amberAccent,
  'black': Colors.black,
  'blue': Colors.blue,
  'blueAccent': Colors.blueAccent,
  'blueGrey': Colors.blueGrey,
  'brown': Colors.brown,
  'cyan': Colors.cyan,
  'cyanAccent': Colors.cyanAccent,
  'deepOrange': Colors.deepOrange,
  'deepOrangeAccent': Colors.deepOrangeAccent,
  'deepPurple': Colors.deepPurple,
  'deepPurpleAccent': Colors.deepPurpleAccent,
  'green': Colors.green,
  'greenAccent': Colors.greenAccent,
  'grey': Colors.grey,
  'indigo': Colors.indigo,
  'indigoAccent': Colors.indigoAccent,
  'lightBlue': Colors.lightBlue,
  'lightBlueAccent': Colors.lightBlueAccent,
  'lightGreen': Colors.lightGreen,
  'lightGreenAccent': Colors.lightGreenAccent,
  'lime': Colors.lime,
  'limeAccent': Colors.limeAccent,
  'orange': Colors.orange,
  'orangeAccent': Colors.orangeAccent,
  'pink': Colors.pink,
  'pinkAccent': Colors.pinkAccent,
  'purple': Colors.purple,
  'purpleAccent': Colors.purpleAccent,
  'red': Colors.red,
  'redAccent': Colors.redAccent,
  'teal': Colors.teal,
  'tealAccent': Colors.tealAccent,
  'transparent': Colors.transparent,
  'white': Colors.white,
  'yellow': Colors.yellow,
  'yellowAccent': Colors.yellowAccent,
};

class HexColor extends Color {
  static int _getColorFromHex(String? hexColor) {
    String? tmp;
    if (hexColor != null) {
      if (hexColor.contains('#')) {
        tmp = hexColor.toString().replaceAll('#', '');
      }

      if (hexColor.contains('0x')) {
        tmp = hexColor.substring(4);
      }
    }

    if (!isHexColor(tmp.toString())) return 1;

    hexColor = hexColor?.toUpperCase().replaceAll("#", "").replaceAll('0X', '');
    if (hexColor?.length == 6) {
      hexColor = "FF" + hexColor.toString();
    }

    return int.parse(hexColor.toString(), radix: 16);
  }

  HexColor(final String? hexColor) : super(_getColorFromHex(hexColor));
}

Color strToColor(String color) {
  return colors[color] ?? HexColor(color);
}

//#525874 #FF854125 0xFF587458
Color incColor(String hexColor, int amt) {
  String? opacityStr;

  if (colors[hexColor] != null) {
    return colors[hexColor]!;
  }

  var usePound = false;

  if (hexColor.isEmpty) return Colors.transparent;

  if (hexColor.contains('#')) {
    hexColor = hexColor.toString().replaceAll('#', '');
    usePound = true;
  }

  if (hexColor.contains('0x')) {
    opacityStr = hexColor.substring(0, 4);
    hexColor = hexColor.substring(4);
    usePound = false;
  }

  var num = int.parse(hexColor, radix: 16);

  var r = (num >> 16) + amt;

  if (r > 255) {
    r = 255;
  } else if (r < 0) {
    r = 0;
  }

  var b = ((num >> 8) & 0x00FF) + amt;

  if (b > 255) {
    b = 255;
  } else if (b < 0) {
    b = 0;
  }

  var g = (num & 0x0000FF) + amt;

  if (g > 255) {
    g = 255;
  } else if (g < 0) {
    g = 0;
  }

  int x = b << 8;
  int y = r << 16;
  int z = g | x | y;
  var result = (z).toRadixString(16);

  return strToColor(
      (usePound ? "#" : opacityStr.toString()) + result.toString());
}

//URL
String urlOnlyDomain(String url) {
  String domain = url
      .replaceAll('http://', '')
      .replaceAll('https://', '')
      .replaceAll('www.', '')
      .replaceAll('ww2.', '')
      .replaceAll('ww3.', '')
      .replaceAll('ww4.', '')
      .replaceAll('ww5.', '')
      .replaceAll('www', '')
      .replaceAll('ww2', '')
      .replaceAll('ww3', '')
      .replaceAll('ww4', '')
      .replaceAll('ww5', '');

  if (domain[0] == '.') {
    domain = domain.substring(1);
  }

  return domain;
}

//NUMBERS
String getCurrencyStr(dynamic value, bool showSymbol) {
  value ??= 0;
  NumberFormat formatter =
      NumberFormat.currency(locale: 'pt_BR', symbol: showSymbol ? 'R\$' : '');
  return formatter.format(value);
}

String getNumberStr(double value) {
  return value.toStringAsFixed(2).replaceAll(',', '').replaceAll('.', ',');
}

enum LaunchLinkType {
  genericLink,
  facebook,
  instagram,
  whatsApp,
}

void launchLink({
  required BuildContext context,
  required LaunchLinkType launchLinkType,
  String? account,
  String? url,
  String? message,
  Map<String, String> headers = const <String, String>{},
}) async {
  dynamic _url = launchLinkType == LaunchLinkType.genericLink
      ? url.toString()
      : launchLinkType == LaunchLinkType.whatsApp
          ? "https://wa.me${![
              '',
              null
            ].contains(account) ? '/55${account?.replaceAll(RegExp(r'[^0-9]'), '')}' : ''}/?text=${Uri.encodeComponent(message.toString())}"
          : 'https://${launchLinkType == LaunchLinkType.instagram ? 'instagram' : 'facebook'}.com/$account';

  bool? _canLaunch;
  if ([
    LaunchLinkType.facebook,
    LaunchLinkType.instagram,
  ].contains(launchLinkType)) {
    _canLaunch = await canLaunch(_url.toString());
  } else {
    _canLaunch = true;
  }

  if (_canLaunch) {
    await launch(
      _url,
      universalLinksOnly: true,
      headers: headers,
    );
  } else {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return const AlertDialog(
          title: Text("Erro ao acessar o perfil"),
          content: Text("App não instalado."),
        );
      },
    );
  }
}

// PDF PRINTER
printToPdf(BuildContext context, pw.Widget pdfWidget) {
  Printing.layoutPdf(onLayout: (PdfPageFormat format) async {
    final doc = pw.Document();

    doc.addPage(pw.Page(
        margin: const pw.EdgeInsets.all(10),
        pageFormat: format,
        build: (
          pw.Context context,
        ) {
          return pw.Container(
            width: 240,
            alignment: pw.Alignment.centerLeft,
            child: pdfWidget,
          );
        }));

    return doc.save();
  });
}

//PROGRESS

void showProgress({
  required BuildContext context,
  String? text,
  required Color color,
  required Color textColor,
}) {
  showDialog(
    barrierDismissible: false,
    context: context,
    builder: (BuildContext context) {
      return WillPopScope(
        onWillPop: () async => false,
        child: Material(
          color: Colors.transparent,
          child: StaggeredDotsWaveWidget(
            text: text,
            color: color,
            textColor: textColor,
          ),
        ),
      );
    },
  );
}

void hideProgress({
  required BuildContext context,
}) {
  Navigator.of(context, rootNavigator: true).pop();
}

//DRAWER
void hideCurrVisibleDrawer(BuildContext context) {
  Navigator.pop(context);
}

==> sl7_fwork_flutter-0.0.17.tar.gz: lib/utils.dart <==
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:pdf/pdf.dart';
import 'package:pdf/widgets.dart' as pw;
import 'package:printing/printing.dart';
import 'package:sl7_fwork_flutter/widgets/wait/staggeredDotsWave/staggered_dots_wave.dart';
import 'package:string_validator/string_validator.dart';
import 'package:url_launcher/url_launcher.dart';

final RouteObserver<PageRoute> routeObserver = RouteObserver<PageRoute>();

//LAYOUT
enum Layouts {
  fullDrawer,
  onlyTicketDrawer,
  noDrawer,
}

const double screenResolutionFactor = 0;

class ScreenResolutions {
  static double get xs => 600 - screenResolutionFactor;
  static double get sm => 960 - screenResolutionFactor;
  static double get md => 1280 - screenResolutionFactor;
  static double get lg => 1920 - screenResolutionFactor;
  static double get xl => 1921 - screenResolutionFactor;
}

double getScreenResolution(BuildContext context) {
  final width = MediaQuery.of(context).size.width;
  return width <= ScreenResolutions.xs
      ? ScreenResolutions.xs
      : width > ScreenResolutions.xs && width <= ScreenResolutions.sm
          ? ScreenResolutions.sm
          : width > ScreenResolutions.sm && width <= ScreenResolutions.md
              ? ScreenResolutions.md
              : width > ScreenResolutions.md && width <= ScreenResolutions.lg
                  ? ScreenResolutions.lg
                  : ScreenResolutions.xl;
}

Layouts getLayout(BuildContext context) {
  return [ScreenResolutions.xs, ScreenResolutions.sm]
          .contains(getScreenResolution(context))
      ? Layouts.fullDrawer
      : getScreenResolution(context) == ScreenResolutions.md
          ? Layouts.onlyTicketDrawer
          : [ScreenResolutions.lg, ScreenResolutions.xl]
                  .contains(getScreenResolution(context))
              ? Layouts.noDrawer
              : Layouts.fullDrawer;
}

//COLORS
Map<String, Color> colors = {
  'amber': Colors.amber,
  'amberAccent': Colors.amberAccent,
  'black': Colors.black,
  'blue': Colors.blue,
  'blueAccent': Colors.blueAccent,
  'blueGrey': Colors.blueGrey,
  'brown': Colors.brown,
  'cyan': Colors.cyan,
  'cyanAccent': Colors.cyanAccent,
  'deepOrange': Colors.deepOrange,
  'deepOrangeAccent': Colors.deepOrangeAccent,
  'deepPurple': Colors.deepPurple,
  'deepPurpleAccent': Colors.deepPurpleAccent,
  'green': Colors.green,
  'greenAccent': Colors.greenAccent,
  'grey': Colors.grey,
  'indigo': Colors.indigo,
  'indigoAccent': Colors.indigoAccent,
  'lightBlue': Colors.lightBlue,
  'lightBlueAccent': Colors.lightBlueAccent,
  'lightGreen': Colors.lightGreen,
  'lightGreenAccent': Colors.lightGreenAccent,
  'lime': Colors.lime,
  'limeAccent': Colors.limeAccent,
  'orange': Colors.orange,
  'orangeAccent': Colors.orangeAccent,
  'pink': Colors.pink,
  'pinkAccent': Colors.pinkAccent,
  'purple': Colors.purple,
  'purpleAccent': Colors.purpleAccent,
  'red': Colors.red,
  'redAccent': Colors.redAccent,
  'teal': Colors.teal,
  'tealAccent': Colors.tealAccent,
  'transparent': Colors.transparent,
  'white': Colors.white,
  'yellow': Colors.yellow,
  'yellowAccent': Colors.yellowAccent,
};

class HexColor extends Color {
  static int _getColorFromHex(String? hexColor) {
    String? tmp;
    if (hexColor != null) {
      if (hexColor.contains('#')) {
        tmp = hexColor.toString().replaceAll('#', '');
      }

      if (hexColor.contains('0x')) {
        tmp = hexColor.substring(4);
      }
    }

    if (!isHexColor(tmp.toString())) return 1;

    hexColor = hexColor?.toUpperCase().replaceAll("#", "").replaceAll('0X', '');
    if (hexColor?.length == 6) {
      hexColor = "FF" + hexColor.toString();
    }

    return int.parse(hexColor.toString(), radix: 16);
  }

  HexColor(final String? hexColor) : super(_getColorFromHex(hexColor));
}

Color strToColor(String color) {
  return colors[color] ?? HexColor(color);
}

//#525874 #FF854125 0xFF587458
Color incColor(String hexColor, int amt) {
  String? opacityStr;

  if (colors[hexColor] != null) {
    return colors[hexColor]!;
  }

  var usePound = false;

  if (hexColor.isEmpty) return Colors.transparent;

  if (hexColor.contains('#')) {
    hexColor = hexColor.toString().replaceAll('#', '');
    usePound = true;
  }

  if (hexColor.contains('0x')) {
    opacityStr = hexColor.substring(0, 4);
    hexColor = hexColor.substring(4);
    usePound = false;
  }

  var num = int.parse(hexColor, radix: 16);

  var r = (num >> 16) + amt;

  if (r > 255) {
    r = 255;
  } else if (r < 0) {
    r = 0;
  }

  var b = ((num >> 8) & 0x00FF) + amt;

  if (b > 255) {
    b = 255;
  } else if (b < 0) {
    b = 0;
  }

  var g = (num & 0x0000FF) + amt;

  if (g > 255) {
    g = 255;
  } else if (g < 0) {
    g = 0;
  }

  int x = b << 8;
  int y = r << 16;
  int z = g | x | y;
  var result = (z).toRadixString(16);

  return strToColor(
      (usePound ? "#" : opacityStr.toString()) + result.toString());
}

//URL
String urlOnlyDomain(String url) {
  String domain = url
      .replaceAll('http://', '')
      .replaceAll('https://', '')
      .replaceAll('www.', '')
      .replaceAll('ww2.', '')
      .replaceAll('ww3.', '')
      .replaceAll('ww4.', '')
      .replaceAll('ww5.', '')
      .replaceAll('www', '')
      .replaceAll('ww2', '')
      .replaceAll('ww3', '')
      .replaceAll('ww4', '')
      .replaceAll('ww5', '');

  if (domain[0] == '.') {
    domain = domain.substring(1);
  }

  return domain;
}

//NUMBERS
String getCurrencyStr(dynamic value, bool showSymbol) {
  value ??= 0;
  NumberFormat formatter =
      NumberFormat.currency(locale: 'pt_BR', symbol: showSymbol ? 'R\$' : '');
  return formatter.format(value);
}

String getNumberStr(double value) {
  return value.toStringAsFixed(2).replaceAll(',', '').replaceAll('.', ',');
}

enum LaunchLinkType {
  genericLink,
  facebook,
  instagram,
  whatsApp,
}

void launchLink({
  required BuildContext context,
  required LaunchLinkType launchLinkType,
  String? account,
  String? url,
  String? message,
  Map<String, String> headers = const <String, String>{},
}) async {
  dynamic _url = launchLinkType == LaunchLinkType.genericLink
      ? url.toString()
      : launchLinkType == LaunchLinkType.whatsApp
          ? "https://wa.me${![
              '',
              null
            ].contains(account) ? '/55${account?.replaceAll(RegExp(r'[^0-9]'), '')}' : ''}/?text=${Uri.encodeComponent(message.toString())}"
          : 'https://${launchLinkType == LaunchLinkType.instagram ? 'instagram' : 'facebook'}.com/$account';

  bool? _canLaunch;
  if ([
    LaunchLinkType.facebook,
    LaunchLinkType.instagram,
  ].contains(launchLinkType)) {
    _canLaunch = await canLaunch(_url.toString());
  } else {
    _canLaunch = true;
  }

  if (_canLaunch) {
    await launch(
      _url,
      universalLinksOnly: true,
      headers: headers,
    );
  } else {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return const AlertDialog(
          title: Text("Erro ao acessar o perfil"),
          content: Text("App não instalado."),
        );
      },
    );
  }
}

// PDF PRINTER
printToPdf(BuildContext context, pw.Widget pdfWidget) {
  Printing.layoutPdf(onLayout: (PdfPageFormat format) async {
    final doc = pw.Document();

    doc.addPage(pw.Page(
        margin: const pw.EdgeInsets.all(10),
        pageFormat: format,
        build: (
          pw.Context context,
        ) {
          return pw.Container(
            width: 240,
            alignment: pw.Alignment.centerLeft,
            child: pdfWidget,
          );
        }));

    return doc.save();
  });
}

//PROGRESS

void showProgress({
  required BuildContext context,
  String? text,
  required Color color,
  required Color textColor,
}) {
  showDialog(
    barrierDismissible: false,
    context: context,
    builder: (BuildContext context) {
      return WillPopScope(
        onWillPop: () async => false,
        child: Material(
          color: Colors.transparent,
          child: StaggeredDotsWaveWidget(
            text: text,
            color: color,
            textColor: textColor,
          ),
        ),
      );
    },
  );
}

void hideProgress({
  required BuildContext context,
}) {
  Navigator.of(context, rootNavigator: true).pop();
}

//DRAWER
void hideCurrVisibleDrawer(BuildContext context) {
  Navigator.pop(context);
}

showWidget(
  BuildContext context,
  Widget widget,
  String routeName, {
  Object? routeArguments,
  void Function(dynamic value)? onClose,
  void Function()? onBeforeShow,
  bool? progress = true,
  bool? forceRoute = false,
}) {
  if (onBeforeShow != null) {
    onBeforeShow();
  }

  if (getScreenResolution(context) >= ScreenResolutions.md &&
      forceRoute != true) {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          contentPadding: EdgeInsets.zero,
          content: Container(
            width: MediaQuery.of(context).size.width,
            constraints: const BoxConstraints(
              maxWidth: 600,
            ),
            child: widget,
          ),
        );
      },
    ).then((value) {
      if (onClose != null) {
        onClose(value);
      }
    });
  } else {
    Navigator.pushNamed(
      context,
      routeName,
      arguments: routeArguments,
    ).then((value) {
      if (onClose != null) {
        onClose(value);
      }
    });
  }
}
